@@ -1,40 +1,21 @@
 //! Main "remote" type for [Vote]()
+use ergo_chain_types::{Base16DecodedBytes, Base16EncodedBytes};
 use thiserror::Error;
 
 use std::convert::{TryFrom, TryInto};
 
-use super::base16_bytes::Base16DecodedBytes;
-use super::base16_bytes::Base16EncodedBytes;
-
 /// Votes for changing system parameters
 #[cfg_attr(feature = "json", derive(serde::Serialize, serde::Deserialize))]
 #[derive(PartialEq, Eq, Debug, Clone)]
 #[cfg_attr(
     feature = "json",
-    serde(into = "Base16EncodedBytes", try_from = "VotesEncodingVariants")
+    serde(
+        into = "Base16EncodedBytes",
+        try_from = "crate::chain::json::votes::VotesEncodingVariants"
+    )
 )]
 pub struct Votes(pub [u8; 3]);
 
-#[cfg_attr(feature = "json", derive(serde::Serialize, serde::Deserialize))]
-#[derive(Debug, Clone)]
-#[cfg_attr(feature = "json", serde(untagged))]
-#[allow(dead_code)]
-enum VotesEncodingVariants {
-    AsStr(Base16DecodedBytes),
-    AsByteArray(Vec<u8>), // explorer v1
-}
-
-impl TryFrom<VotesEncodingVariants> for Votes {
-    type Error = VotesError;
-
-    fn try_from(value: VotesEncodingVariants) -> Result<Self, Self::Error> {
-        match value {
-            VotesEncodingVariants::AsStr(bytes) => bytes.try_into(),
-            VotesEncodingVariants::AsByteArray(bytes) => bytes.try_into(),
-        }
-    }
-}
-
 impl From<Votes> for Vec<u8> {
     fn from(v: Votes) -> Self {
         v.0.to_vec()
