@@ -3,6 +3,7 @@
 use crate::base16_str::Base16Str;
 use crate::bigint256::BigInt256;
 use crate::chain::ergo_box::ErgoBox;
+use crate::chain::token::TokenId;
 use crate::mir::value::CollKind;
 use crate::serialization::SigmaParsingError;
 use crate::serialization::SigmaSerializable;
@@ -17,9 +18,13 @@ use crate::types::stype::LiftIntoSType;
 use crate::types::stype::SType;
 use ergo_chain_types::ADDigest;
 use ergo_chain_types::Base16DecodedBytes;
+use ergo_chain_types::Digest32;
 use impl_trait_for_tuples::impl_for_tuples;
+use sigma_util::AsVecI8;
+use sigma_util::AsVecU8;
 use std::convert::TryFrom;
 use std::convert::TryInto;
+use std::fmt::Formatter;
 use std::rc::Rc;
 
 mod constant_placeholder;
@@ -34,7 +39,7 @@ use super::value::Value;
 
 use thiserror::Error;
 
-#[derive(PartialEq, Eq, Debug, Clone)]
+#[derive(PartialEq, Eq, Clone)]
 /// Constant
 pub struct Constant {
     /// Constant type
@@ -43,9 +48,11 @@ pub struct Constant {
     pub v: Literal,
 }
 
-#[derive(PartialEq, Eq, Debug, Clone)]
+#[derive(PartialEq, Eq, Clone)]
 /// Possible values for `Constant`
 pub enum Literal {
+    /// Unit
+    Unit,
     /// Boolean
     Boolean(bool),
     /// i8
@@ -74,6 +81,36 @@ pub enum Literal {
     Tup(TupleItems<Literal>),
 }
 
+impl std::fmt::Debug for Constant {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        format!("{:?}: {:?}", self.v, self.tpe).fmt(f)
+    }
+}
+
+impl std::fmt::Debug for Literal {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Literal::Coll(CollKind::NativeColl(NativeColl::CollByte(i8_bytes))) => {
+                base16::encode_lower(&i8_bytes.as_vec_u8()).fmt(f)
+            }
+            Literal::Coll(CollKind::WrappedColl { elem_tpe: _, items }) => items.fmt(f),
+            Literal::Opt(boxed_opt) => boxed_opt.fmt(f),
+            Literal::Tup(items) => items.fmt(f),
+            Literal::Unit => ().fmt(f),
+            Literal::Boolean(v) => v.fmt(f),
+            Literal::Byte(v) => v.fmt(f),
+            Literal::Short(v) => v.fmt(f),
+            Literal::Int(v) => v.fmt(f),
+            Literal::Long(v) => v.fmt(f),
+            Literal::BigInt(v) => v.fmt(f),
+            Literal::SigmaProp(v) => v.fmt(f),
+            Literal::GroupElement(v) => v.fmt(f),
+            Literal::AvlTree(v) => v.fmt(f),
+            Literal::CBox(v) => v.fmt(f),
+        }
+    }
+}
+
 impl From<bool> for Literal {
     fn from(v: bool) -> Literal {
         Literal::Boolean(v)
@@ -136,12 +173,25 @@ impl From<ErgoBox> for Literal {
 
 impl From<Vec<u8>> for Literal {
     fn from(v: Vec<u8>) -> Self {
+        Literal::Coll(CollKind::NativeColl(NativeColl::CollByte(v.as_vec_i8())))
+    }
+}
+
+impl From<Digest32> for Literal {
+    fn from(v: Digest32) -> Self {
+        let bytes: Vec<u8> = v.into();
         Literal::Coll(CollKind::NativeColl(NativeColl::CollByte(
-            v.into_iter().map(|b| b as i8).collect(),
+            bytes.as_vec_i8(),
         )))
     }
 }
 
+impl From<TokenId> for Literal {
+    fn from(v: TokenId) -> Self {
+        Digest32::from(v).into()
+    }
+}
+
 impl From<Vec<i8>> for Literal {
     fn from(v: Vec<i8>) -> Literal {
         Literal::Coll(CollKind::NativeColl(NativeColl::CollByte(v)))
@@ -174,6 +224,10 @@ impl TryFrom<Value> for Constant {
             Value::Int(i) => Ok(Constant::from(i)),
             Value::Long(l) => Ok(Constant::from(l)),
             Value::BigInt(b) => Ok(Constant::from(b)),
+            Value::Unit => Ok(Constant {
+                tpe: SType::SUnit,
+                v: Literal::Unit,
+            }),
             Value::SigmaProp(s) => Ok(Constant::from(*s)),
             Value::GroupElement(e) => Ok(Constant::from(*e)),
             Value::CBox(i) => Ok(Constant::from(i)),
@@ -327,6 +381,21 @@ impl From<Vec<u8>> for Constant {
     }
 }
 
+impl From<Digest32> for Constant {
+    fn from(v: Digest32) -> Self {
+        Constant {
+            tpe: SType::SColl(Box::new(SType::SByte)),
+            v: v.into(),
+        }
+    }
+}
+
+impl From<TokenId> for Constant {
+    fn from(v: TokenId) -> Self {
+        Digest32::from(v).into()
+    }
+}
+
 impl From<Vec<i8>> for Constant {
     fn from(v: Vec<i8>) -> Constant {
         Constant {
@@ -606,6 +675,22 @@ impl TryExtractFrom<Literal> for Vec<u8> {
     }
 }
 
+impl TryExtractFrom<Literal> for Digest32 {
+    fn try_extract_from(v: Literal) -> Result<Self, TryExtractFromError> {
+        use sigma_util::FromVecI8;
+        let bytes = Vec::<i8>::try_extract_from(v).map(Vec::<u8>::from_vec_i8)?;
+        Digest32::try_from(bytes).map_err(|e| {
+            TryExtractFromError(format!("failed to extract Digest32 with error: {:?}", e))
+        })
+    }
+}
+
+impl TryExtractFrom<Literal> for TokenId {
+    fn try_extract_from(v: Literal) -> Result<Self, TryExtractFromError> {
+        Digest32::try_extract_from(v).map(Into::into)
+    }
+}
+
 impl TryExtractFrom<Literal> for Literal {
     fn try_extract_from(v: Literal) -> Result<Self, TryExtractFromError> {
         Ok(v)
@@ -954,9 +1039,22 @@ pub mod tests {
 
         #[test]
         fn vec_u8_roundtrip(v in any::<Vec<u8>>()) {
+            // eprintln!("{:?}", Constant::from(v.clone()));
             test_constant_roundtrip(v);
         }
 
+        #[test]
+        fn token_id_roundtrip(v in any::<TokenId>()) {
+            // eprintln!("{:?}", Constant::from(v.clone()));
+            test_constant_roundtrip(v);
+        }
+
+        #[test]
+        fn digest32_roundtrip(v in any::<Digest32>()) {
+            test_constant_roundtrip(v);
+        }
+
+
         #[test]
         fn vec_i16_roundtrip(v in any::<Vec<i16>>()) {
             test_constant_roundtrip(v);
@@ -969,18 +1067,21 @@ pub mod tests {
 
         #[test]
         fn vec_i64_roundtrip(v in any::<Vec<i64>>()) {
+            // eprintln!("{:?}", Constant::from(v.clone()));
             test_constant_roundtrip(v);
         }
 
         #[test]
         fn vec_bigint_roundtrip(raw in any::<Vec<i64>>()) {
             let v: Vec<BigInt256> = raw.into_iter().map(BigInt256::from).collect();
+            // eprintln!("{:?}", Constant::from(v.clone()));
             test_constant_roundtrip(v);
         }
 
         #[test]
         fn vec_option_bigint_roundtrip(raw in any::<Vec<i64>>()) {
             let v: Vec<Option<BigInt256>> = raw.into_iter().map(|i| Some(BigInt256::from(i))).collect();
+            // eprintln!("{:?}", Constant::from(v.clone()));
             test_constant_roundtrip(v);
         }
 
@@ -996,6 +1097,7 @@ pub mod tests {
 
         #[test]
         fn option_nested_vector_type_roundtrip(v in any::<Option<Vec<(i64, bool)>>>()) {
+            // eprintln!("{:?}", Constant::from(v.clone()));
             test_constant_roundtrip(v);
         }
 
@@ -1007,6 +1109,8 @@ pub mod tests {
 
         #[test]
         fn tuple_primitive_types_roundtrip(v in any::<(i64, bool)>()) {
+            // let constant: Constant = v.into();
+            // eprintln!("{:?}", constant);
             test_constant_roundtrip(v);
         }
 
