@@ -62,8 +62,7 @@ impl EcPoint {
     pub fn from_base16_str(str: String) -> Option<Self> {
         base16::decode(&str)
             .ok()
-            .map(|bytes| Self::sigma_parse_bytes(&bytes).ok())
-            .flatten()
+            .and_then(|bytes| Self::sigma_parse_bytes(&bytes).ok())
     }
 }
 
@@ -80,7 +79,7 @@ impl From<EcPoint> for String {
         #[allow(clippy::unwrap_used)]
         {
             let bytes = value.sigma_serialize_bytes().unwrap();
-            String::from_utf8(bytes).unwrap()
+            base16::encode_lower(&bytes)
         }
     }
 }
